Flask-Velox
===========

``Flask-Velox`` is a Flask extension designed to provide ready made View and
Mixin  classes to help rapidly build Flask applications for both public and
admin systems, based on Flasks pluggable ``MethodView``.

Here at `SOON_`_ we use Flask a lot and we wanted a framework we could use
across all our products. As our products and requirements grow so
will ``Flask-Velox``. It is early days but the absolute
basics are there and we would love feedback and help to grow this further.

Projects Using ``Flask-Velox``
------------------------------

* http://thisissoon.com | http://github.com/thisissoon/thisissoon.com
* Pravis (Coming Soon) | http://github.com/thisissoon/pravis

Documentation
-------------

Full documentation can be found here: http://flask-velox.readthedocs.org/

.. _`SOON_`: http://thisissoon.com
